"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2
import dbtlabs.proto.public.v1.events.vortex_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PageLoad(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___PageLoad = PageLoad

@typing.final
class CatalogLiteOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___CatalogLiteOpen = CatalogLiteOpen

@typing.final
class QueryHistoryOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___QueryHistoryOpen = QueryHistoryOpen

@typing.final
class BookmarksOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___BookmarksOpen = BookmarksOpen

@typing.final
class BookmarksOpenDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___BookmarksOpenDetails = BookmarksOpenDetails

@typing.final
class BookmarksEditDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___BookmarksEditDetails = BookmarksEditDetails

@typing.final
class VersionHistoryOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___VersionHistoryOpen = VersionHistoryOpen

@typing.final
class CopilotOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___CopilotOpen = CopilotOpen

@typing.final
class CopilotCreateChat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___CopilotCreateChat = CopilotCreateChat

@typing.final
class CopilotAddCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    COPILOT_REQUEST_ID_FIELD_NUMBER: builtins.int
    copilot_request_id: builtins.str
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        copilot_request_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["copilot_request_id", b"copilot_request_id", "ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___CopilotAddCode = CopilotAddCode

@typing.final
class CopilotFeedbackGood(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    COPILOT_REQUEST_ID_FIELD_NUMBER: builtins.int
    copilot_request_id: builtins.str
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        copilot_request_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["copilot_request_id", b"copilot_request_id", "ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___CopilotFeedbackGood = CopilotFeedbackGood

@typing.final
class CopilotFeedbackBad(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    COPILOT_REQUEST_ID_FIELD_NUMBER: builtins.int
    copilot_request_id: builtins.str
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        copilot_request_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["copilot_request_id", b"copilot_request_id", "ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___CopilotFeedbackBad = CopilotFeedbackBad

@typing.final
class ChartsOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___ChartsOpen = ChartsOpen

@typing.final
class ChartsConfigOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___ChartsConfigOpen = ChartsConfigOpen

@typing.final
class ShareCreateLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___ShareCreateLink = ShareCreateLink

@typing.final
class ShareOpenLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___ShareOpenLink = ShareOpenLink

@typing.final
class ShareCopyToNewQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___ShareCopyToNewQuery = ShareCopyToNewQuery

@typing.final
class CsvDownload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    FILE_SIZE_BYTES_FIELD_NUMBER: builtins.int
    file_size_bytes: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        file_size_bytes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment", "file_size_bytes", b"file_size_bytes"]) -> None: ...

global___CsvDownload = CsvDownload

@typing.final
class RunQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    SQL_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    sql: builtins.str
    error: builtins.str
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def context(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        context: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        sql: builtins.str = ...,
        error: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["context", b"context", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["context", b"context", "enrichment", b"enrichment", "error", b"error", "sql", b"sql"]) -> None: ...

global___RunQuery = RunQuery

@typing.final
class HandoffOpenSqlInStudio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___HandoffOpenSqlInStudio = HandoffOpenSqlInStudio

@typing.final
class HandoffOpenSqlInCanvas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___HandoffOpenSqlInCanvas = HandoffOpenSqlInCanvas

@typing.final
class HandoffOpenModelInCatalog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___HandoffOpenModelInCatalog = HandoffOpenModelInCatalog

@typing.final
class Acknowledge2025LaunchTrialBanner(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

global___Acknowledge2025LaunchTrialBanner = Acknowledge2025LaunchTrialBanner



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.events.vortex_pb2
import dbtlabs.proto.public.v1.fields.vscode_types_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ExtensionActivated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    OS_NAME_FIELD_NUMBER: builtins.int
    OS_VERSION_FIELD_NUMBER: builtins.int
    INIT_SUCCESS_FIELD_NUMBER: builtins.int
    INIT_ERROR_FIELD_NUMBER: builtins.int
    INIT_ERROR_DETAIL_FIELD_NUMBER: builtins.int
    INIT_DURATION_MS_FIELD_NUMBER: builtins.int
    os_name: builtins.str
    """os name"""
    os_version: builtins.str
    """os version"""
    init_success: builtins.bool
    """whether the extension was able to initialize successfully"""
    init_error: builtins.str
    """type of initializion error, if an error occurred at initialization"""
    init_error_detail: builtins.str
    """detailed error message, if an error occurred at initialization"""
    init_duration_ms: builtins.int
    """duration of the initialization in milliseconds"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        os_name: builtins.str = ...,
        os_version: builtins.str = ...,
        init_success: builtins.bool = ...,
        init_error: builtins.str = ...,
        init_error_detail: builtins.str = ...,
        init_duration_ms: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "init_duration_ms", b"init_duration_ms", "init_error", b"init_error", "init_error_detail", b"init_error_detail", "init_success", b"init_success", "os_name", b"os_name", "os_version", b"os_version", "user", b"user"]) -> None: ...

global___ExtensionActivated = ExtensionActivated

@typing.final
class ExtensionLspCompile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    ADAPTER_TYPE_FIELD_NUMBER: builtins.int
    ADAPTER_UNIQUE_ID_FIELD_NUMBER: builtins.int
    DBT_VERSION_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """this is the hash of the project's name, used for anonymized telemetry"""
    adapter_type: builtins.str
    """the type of adapter used in the project (snowflake, bigquery, etc)"""
    adapter_unique_id: builtins.str
    """the unique id of the adapter used in the active profile eg. md5(hostname)"""
    dbt_version: builtins.str
    """the version of dbt used in the project"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        project_id: builtins.str = ...,
        adapter_type: builtins.str = ...,
        adapter_unique_id: builtins.str = ...,
        dbt_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adapter_type", b"adapter_type", "adapter_unique_id", b"adapter_unique_id", "dbt_version", b"dbt_version", "editor", b"editor", "enrichment", b"enrichment", "project_id", b"project_id", "user", b"user"]) -> None: ...

global___ExtensionLspCompile = ExtensionLspCompile



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/fields/vscode_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1dbtlabs/proto/public/v1/fields/vscode_types.proto\x12\x1dv1.public.fields.vscode_types\"u\n\x04User\x12\x1a\n\x12\x63redentials_source\x18\x01 \x01(\t\x12\x19\n\x11\x64\x62t_cloud_user_id\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x62t_cloud_hostname\x18\x03 \x01(\t\x12\x1a\n\x12registration_state\x18\x04 \x01(\t\"\x90\x01\n\x06\x45\x64itor\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nmachine_id\x18\x02 \x01(\t\x12\x16\n\x0emac_machine_id\x18\x03 \x01(\t\x12\x19\n\x11\x65xtension_version\x18\x04 \x01(\t\x12\x13\n\x0b\x65\x64itor_name\x18\x05 \x01(\t\x12\x16\n\x0e\x65\x64itor_version\x18\x06 \x01(\tB@Z>github.com/dbt-labs/proto-golang/v1/public/fields/vscode_typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.fields.vscode_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/fields/vscode_types'
  _globals['_USER']._serialized_start=84
  _globals['_USER']._serialized_end=201
  _globals['_EDITOR']._serialized_start=204
  _globals['_EDITOR']._serialized_end=348
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    """User information"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIALS_SOURCE_FIELD_NUMBER: builtins.int
    DBT_CLOUD_USER_ID_FIELD_NUMBER: builtins.int
    DBT_CLOUD_HOSTNAME_FIELD_NUMBER: builtins.int
    REGISTRATION_STATE_FIELD_NUMBER: builtins.int
    credentials_source: builtins.str
    """source used to get credentials for the user (dbt_cloud.yml, web)"""
    dbt_cloud_user_id: builtins.str
    """dbt cloud user id, can be null if the user is not registered"""
    dbt_cloud_hostname: builtins.str
    """dbt cloud hostname, can be null if the user is not registered"""
    registration_state: builtins.str
    """registration state as reported by the vscode extension"""
    def __init__(
        self,
        *,
        credentials_source: builtins.str = ...,
        dbt_cloud_user_id: builtins.str = ...,
        dbt_cloud_hostname: builtins.str = ...,
        registration_state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["credentials_source", b"credentials_source", "dbt_cloud_hostname", b"dbt_cloud_hostname", "dbt_cloud_user_id", b"dbt_cloud_user_id", "registration_state", b"registration_state"]) -> None: ...

global___User = User

@typing.final
class Editor(google.protobuf.message.Message):
    """Editor and extension information"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    MACHINE_ID_FIELD_NUMBER: builtins.int
    MAC_MACHINE_ID_FIELD_NUMBER: builtins.int
    EXTENSION_VERSION_FIELD_NUMBER: builtins.int
    EDITOR_NAME_FIELD_NUMBER: builtins.int
    EDITOR_VERSION_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """session id (reported by the editor)"""
    machine_id: builtins.str
    """machine id (reported by the editor)"""
    mac_machine_id: builtins.str
    """hashed mac address (reported by the editor)"""
    extension_version: builtins.str
    """version of the dbt extension"""
    editor_name: builtins.str
    """editor name (reported by the editor)"""
    editor_version: builtins.str
    """editor version (reported by the editor)"""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        machine_id: builtins.str = ...,
        mac_machine_id: builtins.str = ...,
        extension_version: builtins.str = ...,
        editor_name: builtins.str = ...,
        editor_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["editor_name", b"editor_name", "editor_version", b"editor_version", "extension_version", b"extension_version", "mac_machine_id", b"mac_machine_id", "machine_id", b"machine_id", "session_id", b"session_id"]) -> None: ...

global___Editor = Editor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/vscode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2
from dbtlabs.proto.public.v1.fields import vscode_types_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_fields_dot_vscode__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dbtlabs/proto/public/v1/events/vscode.proto\x12\x15v1.public.events.vsce\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\x1a\x31\x64\x62tlabs/proto/public/v1/fields/vscode_types.proto\"\xcb\x02\n\x12\x45xtensionActivated\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x0f\n\x07os_name\x18\x04 \x01(\t\x12\x12\n\nos_version\x18\x05 \x01(\t\x12\x14\n\x0cinit_success\x18\x06 \x01(\x08\x12\x12\n\ninit_error\x18\x07 \x01(\t\x12\x19\n\x11init_error_detail\x18\x08 \x01(\t\x12\x18\n\x10init_duration_ms\x18\t \x01(\x03:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xa2\x02\n\x13\x45xtensionLspCompile\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x05 \x01(\t\x12\x19\n\x11\x61\x64\x61pter_unique_id\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x62t_version\x18\x07 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\x42\x38Z6github.com/dbt-labs/proto-golang/v1/public/events/vsceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.vscode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dbt-labs/proto-golang/v1/public/events/vsce'
  _globals['_EXTENSIONACTIVATED']._loaded_options = None
  _globals['_EXTENSIONACTIVATED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONLSPCOMPILE']._loaded_options = None
  _globals['_EXTENSIONLSPCOMPILE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONACTIVATED']._serialized_start=220
  _globals['_EXTENSIONACTIVATED']._serialized_end=551
  _globals['_EXTENSIONLSPCOMPILE']._serialized_start=554
  _globals['_EXTENSIONLSPCOMPILE']._serialized_end=844
# @@protoc_insertion_point(module_scope)
